<?php

namespace Article\Article\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Article\Article\Models\Article;

class ArticlePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the article.
     *
     * @param User $user
     * @param Article $article
     *
     * @return bool
     */
    public function view(User $user, Article $article)
    {
        if ($user->canDo('article.article.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $article->user_id;
    }

    /**
     * Determine if the given user can create a article.
     *
     * @param User $user
     * @param Article $article
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('article.article.create');
    }

    /**
     * Determine if the given user can update the given article.
     *
     * @param User $user
     * @param Article $article
     *
     * @return bool
     */
    public function update(User $user, Article $article)
    {
        if ($user->canDo('article.article.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $article->user_id;
    }

    /**
     * Determine if the given user can delete the given article.
     *
     * @param User $user
     * @param Article $article
     *
     * @return bool
     */
    public function delete(User $user, Article $article)
    {
        if ($user->canDo('article.article.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $article->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
